/***********************************************************************************************************************
 *
 * blueBill Mobile - Android - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile
 * SCM: https://java.net/hg/bluebill-mobile~android-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.mobile.news;

import javax.annotation.Nonnull;
import it.tidalwave.util.thread.annotation.ThreadConfined;
import it.tidalwave.semantic.rss.RssFeed;
import static it.tidalwave.util.thread.ThreadType.*;

/***********************************************************************************************************************
 *
 * @stereotype Service
 * 
 * @navassoc - - - NewsPreferences
 * @navassoc - notify - AvailabilityNotifier
 * @opt noinferrel
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public interface NewsService
  {
    /*******************************************************************************************************************
     *
     * A continuation to confirm to download the news feed from the network.
     * 
     * @stereotype Callback
     * 
     * @navassoc - "confirm download" - NewsService
     * @opt noinferrel
     *
     ******************************************************************************************************************/
    //@bluebook-begin DownloadConfirmation
    public static interface DownloadConfirmation
      {
        /***************************************************************************************************************
         *
         * Downloads the feed from the network. The availability status will be asynchronously notified to the
         * continuation that initiated the conversation.
         *
         **************************************************************************************************************/
        @ThreadConfined(type=ANY)
        public void confirmDownload();
      }
    //@bluebook-end DownloadConfirmation
    
    /*******************************************************************************************************************
     *
     * A continuation to notify the availability status of the news feed.
     * 
     * @stereotype Callback
     * 
     * @navassoc - notify - DownloadConfirmation
     * @opt noinferrel
     *
     ******************************************************************************************************************/
    //@bluebook-begin AvailabilityNotifier
    public static interface AvailabilityNotifier
      {
        /***************************************************************************************************************
         *
         * Notifies that there's a news feed available.
         * 
         * @param newsFeed  the news feed
         *
         **************************************************************************************************************/
        @ThreadConfined(type=NOT_UI)
        public void notifyFeedAvailable (@Nonnull RssFeed newsFeed);

        /***************************************************************************************************************
         *
         * Notifies that there's an obsolete news feed available.
         * 
         * @param newsFeed  the news feed
         *
         **************************************************************************************************************/
        @ThreadConfined(type=NOT_UI)
        public void notifyCachedFeedAvailable (@Nonnull RssFeed newsFeed);
        
        /***************************************************************************************************************
         *
         * Notifies that there's no news feed available.
         *
         **************************************************************************************************************/
        @ThreadConfined(type=NOT_UI)
        public void notifyFeedUnavailable();

        /***************************************************************************************************************
         *
         * Notifies that there's need to download the news feed from the network and the operation could be performed.
         * 
         * @param confirmation   a continuation to confirm the download
         *
         **************************************************************************************************************/
        @ThreadConfined(type=NOT_UI)
        public void notifyFeedCouldBeDownloaded (@Nonnull DownloadConfirmation confirmation);
      }
    //@bluebook-end AvailabilityNotifier
    
    /*******************************************************************************************************************
     *
     * If connecting to the network is allowed, checks for updates and eventually downloads them.
     *
     ******************************************************************************************************************/
    @ThreadConfined(type=ANY)
    public void eventuallyCheckForUpdates();

    /*******************************************************************************************************************
     *
     * Gets the news feed. The availability status will be asynchronously notified to the given continuation.
     * 
     * @param  availabilityNotifier  the continuation to notify the availability status of the news feed
     *
     ******************************************************************************************************************/
    @ThreadConfined(type=ANY)
    public void getNewsFeed (@Nonnull AvailabilityNotifier availabilityNotifier);
  }
