/***********************************************************************************************************************
 *
 * blueBill Mobile - Android - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile
 * SCM: https://java.net/hg/bluebill-mobile~android-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.mobile.news.impl;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;
import java.io.IOException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import it.tidalwave.semantic.document.Document;
import it.tidalwave.bluebill.mobile.news.Readable;
import lombok.RequiredArgsConstructor;

/***********************************************************************************************************************
 *
 * @stereotype Role
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Immutable @RequiredArgsConstructor
public class DocumentReadable implements Readable
  {
    private static final Logger log = LoggerFactory.getLogger(DocumentReadable.class);
    
    @Nonnull
    private final Document message;
    
    @Nonnull
    private final ReadMessagesLog readMessagesLog;

    /*******************************************************************************************************************
     *
     * {@inheritDoc}
     *
     ******************************************************************************************************************/
    @Override 
    public void markAsRead()
      {
        try
          {
            readMessagesLog.markRead(message);
          } 
        catch (IOException e) 
          {
            log.warn("markAsRead()", e);
          }
      }

    /*******************************************************************************************************************
     *
     * {@inheritDoc}
     *
     ******************************************************************************************************************/
    @Override 
    public void markAsNotRead()
      {
        try
          {
            readMessagesLog.markNotRead(message);
          } 
        catch (IOException e) 
          {
            log.warn("markAsNotRead()", e);
          }
      }

    /*******************************************************************************************************************
     *
     * {@inheritDoc}
     *
     ******************************************************************************************************************/
    @Override
    public boolean isRead()
      {
        return readMessagesLog.isRead(message);
      }

    public void read() 
      {
        throw new UnsupportedOperationException("Not supported yet.");
      }
  }
