/***********************************************************************************************************************
 *
 * blueBill Mobile - Android - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile
 * SCM: https://java.net/hg/bluebill-mobile~android-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.mobile.news.impl;

import javax.annotation.Nonnull;
import javax.swing.Action;
import it.tidalwave.util.ui.FlowController;
import it.tidalwave.role.ui.PresentationModel;
import it.tidalwave.semantic.rss.RssFeed;
import it.tidalwave.bluebill.mobile.news.Readable;
import it.tidalwave.bluebill.mobile.news.ui.NewsView;
import lombok.RequiredArgsConstructor;
import static it.tidalwave.semantic.document.Document.Document;
import static it.tidalwave.bluebill.mobile.news.Readable.Readable;

/***********************************************************************************************************************
 *
 * The default implementation of {@link Readable} for the {@link PresentationModel} of a news item. It decorates the
 * {@code Readable} in the item to provide interaction with the UI.
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@RequiredArgsConstructor
public class MessagePresentationModelReadable implements Readable
  {
    private static final Class<RssFeed> RssFeed = RssFeed.class; // FIXME
    
    @Nonnull
    private final PresentationModel messagePM;

    @Nonnull
    private final PresentationModel newsFeedPM;

    @Nonnull
    private final NewsView view;

    @Nonnull
    private final Action markAllMessagesAsReadAction;

    @Nonnull
    private final FlowController flowController;

    public boolean isRead() 
      {
        return messagePM.as(Document).as(Readable).isRead();
      }

    public void markAsRead()
      {
        messagePM.as(Document).as(Readable).markAsRead();
        markAllMessagesAsReadAction.setEnabled(!newsFeedPM.as(RssFeed).as(Readable).isRead());
        view.populate(newsFeedPM); // FIXME: fire an event instead to rerender the single message
      }

    public void markAsNotRead()
      {
        messagePM.as(Document).as(Readable).markAsNotRead();
        markAllMessagesAsReadAction.setEnabled(true);
        view.populate(newsFeedPM); // FIXME: fire an event instead to rerender the single message
      }

    public void read()
      {
        flowController.toNextStep(messagePM.as(Document));
        markAsRead();
      }
  }

